[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) 
[![Coverage Status](https://coveralls.io/repos/github/half-adder/wormAnalysis/badge.svg?branch=master)](https://coveralls.io/github/half-adder/wormAnalysis?branch=master) 
[![Documentation Status](https://readthedocs.org/projects/pharynx-redox/badge/?version=latest)](https://pharynx-redox.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.com/ApfeldLab/pharynx_redox.svg?branch=master)](https://travis-ci.com/ApfeldLab/pharynx_redox)

Documentation: https://pharynx-redox.readthedocs.io/en/latest/
